==> open-xchange-calcengineserver_7.4.0.orig.tar.bz2: open-xchange-calcengineserver-7.4.0/com.openexchange.office.calcengine/src/com/openexchange/office/calcengine/CalcEngineNativeWrapper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.calcengine;

//=============================================================================
/** seams to be some kind of over engineering ... but is useful for testing purposes.
 *  E.g. mocking such JCalcDocumentWrapper isn't an easy job ... we can mock these
 *  implementation instead and write unit tests independent of JNI .-)
 */
public class CalcEngineNativeWrapper
{
    //-------------------------------------------------------------------------
    public static boolean SIMULATE = false;

    //-------------------------------------------------------------------------
    public CalcEngineNativeWrapper ()
        throws Exception
    {}
    
    //-------------------------------------------------------------------------
    public JCalcDocument createDocument()
        throws Exception
    {
        if (SIMULATE)
            return new JCalcDocument(4711);
        return JCalcDocumentWrapper.createDocument();
    }
    
    //-------------------------------------------------------------------------
    public boolean calculate( final JCalcDocument aDocument )
        throws Exception
    {
        if (SIMULATE)
            return true;
        return JCalcDocumentWrapper.calculate(aDocument);
    }
    
    //-------------------------------------------------------------------------
    public boolean destroyDocument(final JCalcDocument aDocument )
        throws Exception
    {
        if (SIMULATE)
            return true;
        return JCalcDocumentWrapper.destroyDocument(aDocument);
    }
    
    //-------------------------------------------------------------------------
    public boolean executeOperation(final JCalcDocument aDocument ,
                                    final JOperation    aOperation)
        throws Exception
    {
        if (SIMULATE)
        {
            aOperation.setResult("{result:\"ok\"}");
            return true;
        }
        return JCalcDocumentWrapper.executeOperation(aDocument, aOperation);
    }
}

==> open-xchange-calcengineserver_7.4.1.orig.tar.bz2: open-xchange-calcengineserver-7.4.1/com.openexchange.office.calcengine/src/com/openexchange/office/calcengine/CalcEngineNativeWrapper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.office.calcengine;

import java.util.UUID;

//=============================================================================
/** seams to be some kind of over engineering ... but is useful for testing purposes.
 *  E.g. mocking such JCalcDocumentWrapper isn't an easy job ... we can mock these
 *  implementation instead and write unit tests independent of JNI .-)
 */
public class CalcEngineNativeWrapper
{
    //-------------------------------------------------------------------------
    public static boolean SIMULATE = false;

    //-------------------------------------------------------------------------
    public CalcEngineNativeWrapper ()
        throws Exception
    {}
    
    //-------------------------------------------------------------------------
    public boolean createDocument(String id)
        throws Exception
    {
        if (SIMULATE)
            return true;
        return JCalcDocumentWrapper.createDocument(id);
    }
    
    //-------------------------------------------------------------------------
    public boolean destroyDocument(final String id )
        throws Exception
    {
        if (SIMULATE)
            return true;
        return JCalcDocumentWrapper.destroyDocument(id);
    }
    
    //-------------------------------------------------------------------------
    public boolean executeOperation(final String id ,
                                    final JOperation    aOperation)
        throws Exception
    {
        if (SIMULATE)
        {
            aOperation.setResult("{result:\"ok\"}");
            return true;
        }
        return JCalcDocumentWrapper.executeOperation(id, aOperation);
    }
    //-------------------------------------------------------------------------
    public String getVersion()
    {
        return JCalcDocumentWrapper.getVersion();
    }
}
